@@ -1,3 +1,4 @@
+import platform
 import stat
 import os
 import csv
@@ -10,9 +11,8 @@ from collections import defaultdict
 
 import click
 
-from ploomber.cli.io import cli_endpoint
 from ploomber.io.terminalwriter import TerminalWriter
-from ploomber.Table import Table
+from ploomber.table import Table
 
 from pygments.formatters.terminal import TerminalFormatter
 from pygments.lexers.markup import MarkdownLexer
@@ -74,8 +74,9 @@ def _list_examples(path):
 
     tw.sep('=', blue=True)
 
-    tw.write(f'\nTo run these examples in a hosted environment: {_URL}\n')
-    tw.write('\nTo copy locally: ploomber examples -n {name}\n\n')
+    tw.write('\nTo run these examples in a hosted '
+             f'environment, see instructions at: {_URL}')
+    tw.write('\nTo get the source code: ploomber examples -n {name}\n\n')
 
 
 class _ExamplesManager:
@@ -103,9 +104,9 @@ class _ExamplesManager:
     def branch(self):
         return self._branch
 
-    def save_metadata(self):
+    def save_metadata(self, branch):
         timestamp = datetime.now().timestamp()
-        metadata = json.dumps(dict(timestamp=timestamp))
+        metadata = json.dumps(dict(timestamp=timestamp, branch=branch))
         self.path_to_metadata.write_text(metadata)
 
     def load_metadata(self):
@@ -143,10 +144,10 @@ class _ExamplesManager:
         if exception:
             raise RuntimeError(
                 'An error occurred when downloading examples. '
-                'Verify git is installed and internet '
+                'Verify git is installed and your internet '
                 f'connection. (Error message: {str(exception)!r})')
 
-        self.save_metadata()
+        self.save_metadata(branch=self.branch)
 
     def outdated(self):
         metadata = self.load_metadata()
@@ -156,12 +157,17 @@ class _ExamplesManager:
             then = datetime.fromtimestamp(timestamp)
             now = datetime.now()
             elapsed = (now - then).days
-            is_outdated = elapsed >= 1
+            is_more_than_one_day_old = elapsed >= 1
 
-            if is_outdated:
-                click.echo('Examples copy is more than 1 day old. Cloning...')
+            is_different_branch = metadata.get('branch') != self.branch
 
-            return is_outdated
+            if is_more_than_one_day_old:
+                click.echo('Examples copy is more than 1 day old...')
+
+            if is_different_branch:
+                click.echo('Different branch requested...')
+
+            return is_more_than_one_day_old or is_different_branch
         else:
             click.echo('Cloning...')
             return True
@@ -173,7 +179,6 @@ class _ExamplesManager:
         return self.examples / 'README.md'
 
 
-@cli_endpoint
 def main(name, force=False, branch=None):
     manager = _ExamplesManager(home=_home, branch=branch)
     tw = TerminalWriter()
@@ -187,15 +192,32 @@ def main(name, force=False, branch=None):
         selected = manager.path_to(name)
 
         if not selected.exists():
-            click.echo(f'There is no example named {name!r}. '
-                       'To get available examples: ploomber examples')
+            click.echo(f'\n\nThere is no example named {name!r}.\n'
+                       'To list examples: ploomber examples\n'
+                       'To update local copy: ploomber examples -f')
         else:
             click.echo(f'Copying example to {name}/')
+
+            if Path(name).exists():
+                raise click.ClickException(
+                    f"{name!r} already exists in the current working "
+                    "directory, please rename it or move it "
+                    "to another location and try again.")
+
             shutil.copytree(selected, name)
+
             path_to_readme = Path(name, 'README.md')
+            path_to_req = Path(name, 'requirements.txt')
+            path_to_env = Path(name, 'environment.yml')
+            name_dir = name + ('\\' if platform.system() == 'Windows' else '/')
 
             tw.sep('=', str(path_to_readme), blue=True)
             _display_markdown(path_to_readme)
             tw.sep('=', blue=True)
-            tw.write(f'Done. Check out {path_to_readme} for details.\n',
-                     green=True)
+            tw.write(
+                f'Done.\n\nTo install dependencies, use any of the following: '
+                f'\n  1. Move to {name_dir} and run "ploomber install"'
+                f'\n  2. conda env create -f {path_to_env}'
+                f'\n  3. pip install -r {path_to_req}'
+                f'\n\nCheck out {path_to_readme} for more details.\n',
+                green=True)
