@@ -60,6 +60,11 @@ class CustomParser(argparse.ArgumentParser):
                           'specified level',
                           default=None)
 
+        self.add_argument('--log-file',
+                          '-F',
+                          help='Enables logging to the given file',
+                          default=None)
+
         if self.DEFAULT_ENTRY_POINT:
             entry_point_help = ('Entry point, defaults '
                                 f'to {self.DEFAULT_ENTRY_POINT}')
@@ -145,9 +150,7 @@ class CustomParser(argparse.ArgumentParser):
 
         args = self.parse_args()
 
-        if hasattr(args, 'log'):
-            if args.log is not None:
-                logging.basicConfig(level=args.log.upper())
+        _configure_logger(args)
 
         # extract required (by using function signature) params from the cli
         # args
@@ -304,9 +307,24 @@ def _add_args_from_callable(parser, callable_):
     required, defaults, params = _parse_signature_from_callable(callable_)
 
     for arg in defaults.keys():
-        parser.add_argument('--' + arg,
-                            help=get_desc(doc, arg),
-                            **add_argument_kwargs(params, arg))
+        conflict = False
+
+        try:
+            parser.add_argument('--' + arg,
+                                help=get_desc(doc, arg),
+                                **add_argument_kwargs(params, arg))
+        except argparse.ArgumentError as e:
+            conflict = e
+
+        if conflict:
+            if 'conflicting option string' in conflict.message:
+                raise ValueError(
+                    f'The signature from {callable_.__name__!r} '
+                    'conflicts with existing arguments in the command-line '
+                    'interface, please rename the following '
+                    f'argument: {arg!r}')
+            else:
+                raise conflict
 
     for arg in required:
         parser.add_argument(arg,
@@ -353,9 +371,7 @@ def _process_file_dir_or_glob(parser, dagspec_arg=None):
     args = parser.parse_args()
     dagspec_arg = dagspec_arg or args.entry_point
 
-    if hasattr(args, 'log'):
-        if args.log is not None:
-            logging.basicConfig(level=args.log.upper())
+    _configure_logger(args)
 
     entry_point = EntryPoint(dagspec_arg)
 
@@ -450,3 +466,16 @@ def _flatten_dict(d, prefix=''):
             out[prefix + k] = v
 
     return out
+
+
+def _configure_logger(args):
+    """Configure logger if user passed --log/--log-file args
+    """
+    if hasattr(args, 'log'):
+        if args.log is not None:
+            logging.basicConfig(level=args.log.upper())
+
+    if hasattr(args, "log_file"):
+        if args.log_file is not None:
+            file_handler = logging.FileHandler(args.log_file)
+            logging.getLogger().addHandler(file_handler)
