@@ -5,6 +5,7 @@ from functools import partial
 from copy import copy
 from pathlib import Path
 from collections.abc import MutableMapping, Mapping
+import platform
 
 from ploomber import tasks, products
 from ploomber.util.util import _make_iterable
@@ -13,6 +14,7 @@ from ploomber.tasks.taskgroup import TaskGroup
 from ploomber import validators
 from ploomber.exceptions import DAGSpecInitializationError
 from ploomber.products._resources import resolve_resources
+from ploomber.io import pretty_print
 
 suffix2taskclass = {
     '.py': tasks.NotebookRunner,
@@ -32,6 +34,14 @@ def _safe_suffix(product):
         return None
 
 
+def _looks_like_path(s):
+    system = platform.system()
+    if system == 'Windows':
+        return '\\' in s
+    else:
+        return '/' in s
+
+
 def task_class_from_source_str(source_str, lazy_import, reload, product):
     """
     The source field in a DAG spec is a string. The actual value needed to
@@ -57,6 +67,11 @@ def task_class_from_source_str(source_str, lazy_import, reload, product):
             return tasks.SQLDump
 
         return suffix2taskclass[extension]
+    elif _looks_like_path(source_str):
+        raise ValueError('Failed to determine task class for '
+                         f'source {source_str!r} (invalid '
+                         f'extension {extension!r}). Valid extensions '
+                         f'are: {pretty_print.iterable(suffix2taskclass)}')
     else:
         try:
             imported = fn_checker(source_str)
@@ -68,7 +83,7 @@ def task_class_from_source_str(source_str, lazy_import, reload, product):
         if imported is None:
             raise ValueError(
                 'Could not determine task class for '
-                f'source {source_str!r} due to error: {error!s}.\n\n'
+                f'source {source_str!r} due to error: {error!s}. '
                 'This looks like a dotted path but it failed to import. '
                 'You can also set the task class using the "class" key.')
         else:
@@ -237,6 +252,10 @@ class TaskSpec(MutableMapping):
         upstream = _make_iterable(data.pop('upstream'))
 
         if 'grid' in data:
+            if 'params' in data:
+                raise KeyError(f'Error initializing task with spec {data!r}: '
+                               '\'params\' is not allowed when using \'grid\'')
+
             if 'name' not in data:
                 raise KeyError(f'Error initializing task with spec {data!r}: '
                                'tasks with \'grid\' must have a \'name\'')
@@ -246,16 +265,35 @@ class TaskSpec(MutableMapping):
             product = data.pop('product')
             name = data.pop('name')
             grid = data.pop('grid')
-            # TODO: support for hooks
-            return TaskGroup.from_grid(
-                task_class=task_class,
-                product_class=product_class,
-                product_primitive=product,
-                task_kwargs=data,
-                dag=dag,
-                name=name,
-                grid=grid,
-                resolve_relative_to=self.project_root), upstream
+
+            # hooks
+            on_render = data.pop('on_render', None)
+            on_finish = data.pop('on_finish', None)
+            on_failure = data.pop('on_failure', None)
+
+            if on_render:
+                on_render = dotted_path.DottedPath(on_render,
+                                                   lazy_load=self.lazy_import)
+
+            if on_finish:
+                on_finish = dotted_path.DottedPath(on_finish,
+                                                   lazy_load=self.lazy_import)
+
+            if on_failure:
+                on_failure = dotted_path.DottedPath(on_failure,
+                                                    lazy_load=self.lazy_import)
+
+            return TaskGroup.from_grid(task_class=task_class,
+                                       product_class=product_class,
+                                       product_primitive=product,
+                                       task_kwargs=data,
+                                       dag=dag,
+                                       name=name,
+                                       grid=grid,
+                                       resolve_relative_to=self.project_root,
+                                       on_render=on_render,
+                                       on_finish=on_finish,
+                                       on_failure=on_failure), upstream
         else:
             return _init_task(data=data,
                               meta=self.meta,
