@@ -267,25 +267,16 @@ class NotebookRunner(FileLoaderMixin, Task):
                  nbconvert_exporter_name=None,
                  ext_in=None,
                  nb_product_key='nb',
-                 static_analysis='warn',
+                 static_analysis=True,
                  nbconvert_export_kwargs=None,
                  local_execution=False,
                  check_if_kernel_installed=True):
-        if static_analysis == 'warn':
-            warnings.warn(
-                "The default value of static_analysis (NotebookRunner) "
-                "will change from False to True in 0.13.1. For details, see "
-                "https://github.com/ploomber/ploomber/issues/336",
-                FutureWarning)
-            static_analysis = False
-
         self.papermill_params = papermill_params or {}
         self.nbconvert_export_kwargs = nbconvert_export_kwargs or {}
         self.kernelspec_name = kernelspec_name
         self.nbconvert_exporter_name = nbconvert_exporter_name
         self.ext_in = ext_in
         self.nb_product_key = nb_product_key
-        self.static_analysis = static_analysis
         self.local_execution = local_execution
         self.check_if_kernel_installed = check_if_kernel_installed
 
@@ -321,6 +312,17 @@ class NotebookRunner(FileLoaderMixin, Task):
                                             nbconvert_exporter_name,
                                             nbconvert_export_kwargs)
 
+    # expose the static_analysis attribute from the source, we need this
+    # since we disable static_analysis when rendering the DAG in Jupyter
+
+    @property
+    def static_analysis(self):
+        return self._source.static_analysis
+
+    @static_analysis.setter
+    def static_analysis(self, value):
+        self._source.static_analysis = value
+
     @staticmethod
     def _init_source(source,
                      kwargs,
